@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0600';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -130,6 +130,19 @@ sub _build_graph {
 }
 
 
+has phrase => (
+    is        => 'rw',
+    init_args => undef,
+);
+
+
+has chords => (
+    is        => 'rw',
+    init_args => undef,
+);
+
+
+
 has verbose => (
     is      => 'ro',
     isa     => sub { croak "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
@@ -170,7 +183,8 @@ sub generate {
     print 'Chord map: ', ddc(\@chord_map) if $self->verbose;
 
     my @phrase = map { $self->_tt_sub(\@chord_map, $_) } @progression;
-    print 'Phrase: ', ddc(\@phrase) if $self->verbose;
+    $self->phrase(\@phrase);
+    print 'Phrase: ', ddc($self->phrase) if $self->verbose;
 
     # Add octaves to the chords
     my $mcn = Music::Chord::Note->new;
@@ -197,7 +211,8 @@ sub generate {
         }
     }
 
-    print 'Chords: ', ddc(\@chords) if $self->verbose;
+    $self->chords(\@chords);
+    print 'Chords: ', ddc($self->chords) if $self->verbose;
 
     return \@chords;
 }
@@ -318,7 +333,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0504
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -485,6 +500,15 @@ The network transition L<Graph> object.  This is a computed attribute.
 
 Default: C<Graph::Directed>
 
+=head2 phrase
+
+The generated phrase of named chords.  This is a computed attribute.
+
+=head2 chords
+
+The generated phrase of individual note chords.  This is a computed
+attribute.
+
 =head2 verbose
 
 Show the B<generate> and B<substitution> progress.
